==> tcl-awthemes_9.5.1.1.orig.tar.xz: awthemes-9.5.1.1/awbreeze.tcl <==
#!/usr/bin/tclsh
#
#   breeze:
#     - Notebook background is not graphical as it was in the original.
#     - Disabled checkbutton/radiobutton look match the enabled look.
#     - readonly combobox is not identical.
#     - toolbutton and menubutton press states are set the same as
#       the button press.
#     - treeview arrow selected color is changed.
#     - sizegrip design is different.
#

set ap [file normalize [file dirname [info script]]]
if { $ap ni $::auto_path } {
  lappend ::auto_path $ap
}
set ap [file normalize [file join [file dirname [info script]] .. code]]
if { $ap ni $::auto_path } {
  lappend ::auto_path $ap
}
unset ap
package require awthemes

namespace eval ::ttk::theme::breeze {

  proc setBaseColors { } {
    variable colors

      # original breeze base foreground is #31363b
      # I personally want as high of a contrast as is possible.
      # the combobox style must be set to -, otherwise the awthemes
      # default (solid-bg) is used.

      array set colors {
          style.arrow           chevron
          style.button          roundedrect-flat
          style.checkbutton     roundedrect-square
          style.combobox        -
          style.entry           roundedrect
          style.labelframe      square
          style.menubutton      chevron
          style.notebook        roundedtop-dark
          style.progressbar     rounded-line
          style.radiobutton     circle-circle
          style.scale           circle
          style.scrollbar-grip  none
          style.treeview        chevron
          bg.bg                 #eff0f1
          fg.fg                 #000000
          graphics.color        #3daee9
      }
  }

  proc setDerivedColors { } {
    variable colors

    # the alternate color would be defined, but we need a copy now
    # for button-af
    set colors(graphics.color.alternate) \
        [::colorutils::opaqueBlendPerc $colors(graphics.color) #ffffff 0.7 2]

    set colors(entrybg.checkbutton) $colors(bg.bg)
    set colors(button.pressed) $colors(graphics.color)
    set colors(border.button.active) $colors(graphics.color)
    set colors(button.active.focus) $colors(graphics.color.alternate)
    set colors(button.anchor) {}
    set colors(button.image.padding) {6 4}
    set colors(button.padding) {8 3}
    set colors(border.checkbutton) $colors(graphics.color)
    set colors(checkbutton.focusthickness) 1
    set colors(checkbutton.padding) {4 0 0 2}
    set colors(combobox.entry.image.padding) {6 8}
    set colors(entrybg.bg) #fcfcfc
    set colors(entry.image.padding) {5 8}
    set colors(entry.padding) {2 0}
    set colors(arrow.color) $colors(bg.darkest)
    set colors(spinbox.color.arrow) $colors(bg.darkest)
    set colors(menubutton.padding) {10 2}
    set colors(menubutton.use.button.image) true
    set colors(parent.theme) default
    set colors(scale.trough)  $colors(graphics.color)
    set colors(scrollbar.has.arrows) false
    set colors(select.bg) $colors(graphics.color)
    set colors(spinbox.image.padding) {4 4}
    set colors(toolbutton.image.padding) {10 7}
    set colors(toolbutton.use.button.image) true
    set colors(tree.arrow.selected) #ffffff
    set colors(trough.color) $colors(bg.darker)
  }

  proc init { } {
    if { ([info exists ::notksvg] && $::notksvg) ||
        [catch {package present tksvg}] } {
      namespace delete ::ttk::theme::breeze
      error "no tksvg package present: cannot load scalable breeze theme"
    }
    package provide breeze 1.7
    ::ttk::awthemes::init breeze
  }

  init
}

==> tcl-awthemes_10.2.0.orig.tar.xz: awthemes-10.2.0/awbreeze.tcl <==
#!/usr/bin/tclsh
#
#   breeze:
#     - Notebook background is not graphical as it was in the original.
#     - Disabled checkbutton/radiobutton look match the enabled look.
#     - readonly combobox is not identical.
#     - toolbutton and menubutton press states are set the same as
#       the button press.
#     - treeview arrow selected color is changed.
#     - sizegrip design is different.
#

set ap [file normalize [file dirname [info script]]]
if { $ap ni $::auto_path } {
  lappend ::auto_path $ap
}
set ap [file normalize [file join [file dirname [info script]] .. code]]
if { $ap ni $::auto_path } {
  lappend ::auto_path $ap
}
unset ap
package require awthemes

namespace eval ::ttk::theme::awbreeze {

  proc setBaseColors { } {
    variable colors

      # original breeze base foreground is #31363b
      # I personally want as high of a contrast as is possible.
      # the combobox style must be set to -, otherwise the awthemes
      # default (solid-bg) is used.

      array set colors {
          style.arrow           chevron
          style.button          roundedrect-flat
          style.checkbutton     roundedrect-square
          style.combobox        -
          style.entry           roundedrect
          style.labelframe      square
          style.menubutton      chevron
          style.notebook        roundedtop-dark
          style.progressbar     rounded-line
          style.radiobutton     circle-circle
          style.scale           circle
          style.scrollbar-grip  none
          style.treeview        chevron
          bg.bg                 #eff0f1
          fg.fg                 #000000
          graphics.color        #3daee9
      }
  }

  proc setDerivedColors { } {
    variable colors

    # the alternate color would be defined, but we need a copy now
    # for button-af
    set colors(graphics.color.alternate) \
        [::colorutils::opaqueBlendPerc $colors(graphics.color) #ffffff 0.7 2]

    set colors(entrybg.checkbutton) $colors(bg.bg)
    set colors(button.pressed) $colors(graphics.color)
    set colors(border.button.active) $colors(graphics.color)
    set colors(button.active.focus) $colors(graphics.color.alternate)
    set colors(button.anchor) {}
    set colors(button.image.padding) {6 4}
    set colors(button.padding) {8 3}
    set colors(border.checkbutton) $colors(graphics.color)
    set colors(checkbutton.focusthickness) 1
    set colors(checkbutton.padding) {4 0 0 2}
    set colors(combobox.entry.image.padding) {6 8}
    set colors(entrybg.bg) #fcfcfc
    set colors(entry.image.padding) {5 8}
    set colors(entry.padding) {2 0}
    set colors(arrow.color) $colors(bg.darkest)
    set colors(spinbox.color.arrow) $colors(bg.darkest)
    set colors(menubutton.padding) {10 2}
    set colors(menubutton.use.button.image) true
    set colors(parent.theme) default
    set colors(scale.trough)  $colors(graphics.color)
    set colors(scrollbar.has.arrows) false
    set colors(select.bg) $colors(graphics.color)
    set colors(spinbox.image.padding) {4 4}
    set colors(toolbutton.image.padding) {10 7}
    set colors(toolbutton.use.button.image) true
    set colors(tree.arrow.selected) #ffffff
    set colors(trough.color) $colors(bg.darker)
  }

  proc init { } {
    set theme awbreeze
    set version 1.8
    if { ([info exists ::notksvg] && $::notksvg) ||
        [catch {package present tksvg}] } {
      namespace delete ::ttk::theme::${theme}
      error "no tksvg package present: cannot load scalable ${theme} theme"
    }
    package provide ${theme} $version
    package provide ttk::theme::${theme} $version
    ::ttk::awthemes::init ${theme}
  }

  init
}
